@@ -44,18 +44,18 @@ SUB_TOOLS={
   "k8s-services":['kind','kubespray','microk8s','kubeadm','minikube','openshift','rancher-k3s','rancher-rke2','smart-edge-open','starlingx','tanzu'],
   "intel-dev-tools":['intel-auto-deploy','intel-auto-test','intel-code-scans','mgt-console'],
   "oneapi-toolkits":['ai-analytics-toolkit','base-toolkit','intel-vtune','iot-toolkit','scikit-learn','xgboost'],
-  "one-edge-building-blocks":['csp-services','inference-services']
+  "one-edge-building-blocks":['csp-services','inference-services','observability-services']
 }
 
 TOOLS={
   "code-editor-tools":['jupyter-notebook','jupyter-lab','atom','sublime-text','notepad++','vscode'],
   "container-runtimes":['docker', 'docker-compose','containerd','cri-o'], 
-  "automation-and-configuration-tools":['ansible','chef','puppet'],  
+  "automation-and-configuration-tools":['ansible','chef','puppet'],
   "dl-model-tools":['dl-model-benchmark', 'nncf', 'omz-tools', 'openvino-dl-workbench','openvino-model-server', 
                     'post-training-optimization-toolkit'],
   "inference-runtimes":['intel-optimized-pytorch', 'intel-optimized-tensorflow','onnx', 'openvino-2022.1', 'openvino-addon-tensorflow'],
   "featured-dl-models":['bert-large-uncased-whole-word-masking-squad-int8-0001','deeplabv3','efficientdet-d0-tf','facenet-20180408-102900','mobilenet-ssd','object-detection-models','resnet-50-pytorch','ssdlite_mobilenet_v2','yolo-v4-tf'],
-  "model-zoo":['pytorch-model-zoo','tensorflow-hub'],
+  "model-zoo":['pytorch-model-zoo','tensorflow-hub','intel-ai-model-zoo','intel-openvino-model-zoo'],
   "data-engineering-tools":['cvat','datumaro'],
   "datasets":['face-detection','face-mask-detection','fake-face-detection','flowers-recognition'],
   "object-detection-models":['face-detection-retail-0005','pedestrian-detection-adas-0002','person-detection-retail-0002','vehicle-detection-adas-0002'],
@@ -72,11 +72,12 @@ TOOLS={
   "retail":['automated-checkout','edgex','interactive-kisok-ai-chatbot','real-time-sensor-fusion-for-loss-detection','social-distancing-for-retail-settings'],
   "safety-security":['edge-aibox-for-video-analytics','edge-insights-for-vision','smart-video-and-ai-workload','social-distancing-for-retail','social-distancing-for-retail-settings'],
   "transportation":['address-recognition-and-analytics','automatic-license-plate-recognition','cargo-management','drive-behavior-analytics','edge-insights-for-fleet','intelligent-traffic-management','public-transit-analytics','vehicle-event-recording','workzone-analytics'],
-  "seo-samples":['openvino-sample-application-in-openness','sample-eaa-test-application','telemetry-sample','video-analytics-services-sample-application-in-openness'],
+  "seo-samples":['sample-cdn-application','smart-city-app','telemetry-sample-app','video-anlaytics-services-sample'],
   "seo-reference-implementations":['intelligent-connection-management-for-automated-handover','smartvr–livestreaming-of-immersive-media','telehealth-remote-monitoring','wireless-network-ready-intelligent-traffic-management','wireless-network-ready-pcb-defect-detection','network-optimization-and-ai-inferencing-management-for-telepathology'],
   "seo-3rd-party-applications":['a5gnetworks','herta','orbo','qwilt','radisys'],
   "csp-services":['aws-greengrass','azure-iot-central','azure-iot-edge','azure-iot-hub'],
-  "inference-services":['dlstreamer','dlstreamer-pipeline-server','openvino-container','openvino-model-server']
+  "inference-services":['dlstreamer','dlstreamer-pipeline-server','openvino-container','openvino-model-server'],
+  "observability-services":['system-telemetry','cluster-telemetry','docker-telemetry','log-analytics']
 
 }
 
